# buddy

A voice command tool that uses ChatGPT as NLU

## Installation

You can install buddy by running the following command:

```bash
pip install buddy
```

## Usage

```code
import buddy

buddy.run()
```

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
